# nitro-bridge-setup

## Setup Ansible

To get started, follow the [installation](../README.md#installation) guide to setup ansible on your machine

## Setup

The following commands have to be executed in the [`nitro-bridge-setup`](./) directory:

- Copy the `bridge-vars.example.yml` vars file:

  ```bash
  cp bridge-vars.example.yml bridge-vars.yml
  ```

- Edit [`bridge-vars.yml`](./bridge-vars.yml) with the required values:

  ```yaml
  # L1 WS endpoint
  nitro_chain_url: ""

  # Private key for the bridge's nitro address
  nitro_sc_pk: ""

  # Private key for a funded account on L1
  # This account should have tokens for funding Nitro channels
  nitro_chain_pk: ""

  # Custom L2 token to be deployed
  token_name: "LaconicNetworkToken"
  token_symbol: "LNT"
  initial_token_supply: "129600"

  # Addresses of the deployed nitro contracts
  na_address: ""
  vpa_address: ""
  ca_address: ""
  ```

## Run Nitro Bridge

### On Local Host

- To setup and run nitro bridge locally, execute the `run-nitro-bridge.yml` Ansible playbook:

  ```bash
  LANG=en_US.utf8 ansible-playbook run-nitro-bridge.yml --extra-vars='{ "target_host": "localhost"}'  --user $USER -kK
  ```

  NOTE: By default, deployments are created in an `out` directory. To change this location, update the `nitro_directory` variable in the [setup-vars.yml](./setup-vars.yml) file

- For skipping container build, set `"skip_container_build" : true` in the `--extra-vars` parameter:

  ```bash
  LANG=en_US.utf8 ansible-playbook run-nitro-bridge.yml --extra-vars='{"target_host" : "localhost", "skip_container_build": true}'  --user $USER -kK
  ```

### On Remote Host

To run the playbook on a remote host:

- Create a new `hosts.ini` file:

   ```bash
   cp ../hosts.example.ini hosts.ini
   ```

- Edit the [`hosts.ini`](./hosts.ini) file to run the playbook on a remote machine:

  ```ini
  [<deployment_host>]
  <host_name> ansible_host=<target_ip> ansible_user=<ssh_user> ansible_ssh_common_args='-o ForwardAgent=yes'
  ```

  - Replace `<deployment_host>` with `nitro_host`
  - Replace `<host_name>` with the alias of your choice
  - Replace `<target_ip>` with the IP address or hostname of the target machine
  - Replace `<ssh_user>` with the SSH username (e.g., dev, ubuntu)

- Verify that you are able to connect to the host using the following command

  ```bash
  ansible all -m ping -i hosts.ini -k

  # Expected output:

  # <host_name> | SUCCESS => {
  #  "ansible_facts": {
  #      "discovered_interpreter_python": "/usr/bin/python3.10"
  #  },
  #  "changed": false,
  #  "ping": "pong"
  # }
  ```

- Execute the `run-nitro-bridge.yml` Ansible playbook for remote deployment:

  ```bash
  LANG=en_US.utf8 ansible-playbook -i hosts.ini run-nitro-bridge.yml --extra-vars='{ "target_host": "nitro_host"}'  --user $USER -kK
  ```

- For skipping container build, run with `"skip_container_build" : true` in the `--extra-vars` parameter:

  ```bash
  LANG=en_US.utf8 ansible-playbook -i hosts.ini run-nitro-bridge.yml --extra-vars='{ "target_host": "nitro_host", "skip_container_build": true }' --user $USER -kK
  ```

## Check Deployment Status

- Run the following command in the directory where the bridge-deployment is created:

  - Check logs for deployments:

    ```bash
    # Check the bridge deployment logs, ensure that the node is running
    laconic-so deployment --dir bridge-deployment logs nitro-bridge -f
    ```
