# nitro-nodes-setup

## Setup Ansible

To get started, follow the [installation](../README.md#installation) guide to setup ansible on your machine

## Setup for Remote Host

To run the playbook on a remote host:

- Follow steps from [setup remote hosts](../README.md#setup-remote-hosts)

- Update / append the [`hosts.ini`](../hosts.ini) file for your remote host with `<deployment_host>` set as `nitro_host`

## Setup

The following commands have to be executed in [`nitro-nodes-setup`](./) directory

- Copy the `nitro-vars.example.yml` vars file

  ```bash
  cp nitro-vars.example.yml nitro-vars.yml
  ```

- Edit [`nitro-vars.yml`](./nitro-vars.yml) and fill in the following values

  ```bash
  # L1 WS endpoint
  nitro_chain_url: ""

  # Private key for your nitro address
  nitro_sc_pk: ""

  # Private key of the account on chain that is used for funding channels in Nitro node
  nitro_chain_pk: ""

  # Contract address of NitroAdjudicator
  na_address: ""

  # Contract address of VirtualPaymentApp
  vpa_address: ""

  # Contract address of ConsensusApp
  ca_address: ""

  # Multiaddr of the L1 bridge node
  nitro_l1_bridge_multiaddr: ""

  # Multiaddr of the L2 bridge node
  nitro_l2_bridge_multiaddr: ""

  # Multiaddr with publically accessible IP address / DNS for your L1 nitro node
  # Example: "/ip4/192.168.x.y/tcp/3009"
  # Example: "/dns4/example.com/tcp/3009"
  nitro_l1_ext_multiaddr: ""

  # Multiaddr with publically accessible IP address / DNS for your L2 nitro node
  nitro_l2_ext_multiaddr: ""
  ```

## Run Nitro Node

### On Local Host

- To run a nitro node, execute the `run-nitro-nodes.yml` Ansible playbook by running the following command:

  ```bash
  LANG=en_US.utf8 ansible-playbook run-nitro-nodes.yml --extra-vars='{ "target_host": "localhost"}' --user $USER -kK
  ```

  NOTE: By default, deployments are created in a `out` directory. To change this location, update the `nitro_directory` variable in the [setup-vars.yml](./setup-vars.yml) file

- For skipping container build, run with `"skip_container_build" : true` in the `--extra-vars` parameter:

  ```bash
  LANG=en_US.utf8 ansible-playbook -i hosts.ini run-nitro-nodes.yml --extra-vars='{ "target_host": "localhost", "skip_container_build": true }' --user $USER -kK
  ```

### On Remote Host

To run the playbook on a remote host:

- Create a new `hosts.ini` file:

   ```bash
   cp ../hosts.example.ini hosts.ini
   ```

- Edit the [`hosts.ini`](./hosts.ini) file to run the playbook on a remote machine:

  ```ini
  [<deployment_host>]
  <host_name> ansible_host=<target_ip> ansible_user=<ssh_user> ansible_ssh_common_args='-o ForwardAgent=yes'
  ```

  - Replace `<deployment_host>` with `nitro_host`
  - Replace `<host_name>` with the alias of your choice
  - Replace `<target_ip>` with the IP address or hostname of the target machine
  - Replace `<ssh_user>` with the SSH username (e.g., dev, ubuntu)

- Verify that you are able to connect to the host using the following command

  ```bash
  ansible all -m ping -i hosts.ini -k

  # Expected output:

  # <host_name> | SUCCESS => {
  #  "ansible_facts": {
  #      "discovered_interpreter_python": "/usr/bin/python3.10"
  #  },
  #  "changed": false,
  #  "ping": "pong"
  # }
  ```

- Copy and edit the [`nitro-vars.yml`](./nitro-vars.yml) file as described in the [local setup](./README.md#run-nitro-node-on-local-host) section

- Execute the `run-nitro-nodes.yml` Ansible playbook for remote deployment:

  ```bash
  LANG=en_US.utf8 ansible-playbook -i hosts.ini run-nitro-nodes.yml --extra-vars='{ "target_host": "nitro_host"}' --user $USER -kK
  ```

- For skipping container build, run with `"skip_container_build" : true` in the `--extra-vars` parameter:

  ```bash
  LANG=en_US.utf8 ansible-playbook -i hosts.ini run-nitro-nodes.yml --extra-vars='{ "target_host": "nitro_host", "skip_container_build": true }' --user $USER -kK
  ```


## Check Deployment Status

- Run the following command in the directory where the deployments are created

  - Check L1 nitro node logs:

    ```bash
    laconic-so deployment --dir l1-nitro-deployment logs nitro-node -f
    ```

  - Check L2 nitro node logs:

    ```bash
    laconic-so deployment --dir l2-nitro-deployment logs nitro-node -f
    ```
